/*******************************************************************************
 * Copyright (c) 2004, 2015 IBM Corporation and others.
 *
 * This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License 2.0
 * which accompanies this distribution, and is available at
 * https://www.eclipse.org/legal/epl-2.0/
 *
 * SPDX-License-Identifier: EPL-2.0
 *
 * Contributors:
 *     IBM Corporation - initial API and implementation
 *******************************************************************************/

package org.eclipse.ui.internal.handlers;

import org.eclipse.ui.IWorkbenchWindowActionDelegate;

/**
 * Allows handlers to be contributed to through action sets.
 *
 * @since 3.1
 */
public interface IWorkbenchWindowHandlerDelegate extends IWorkbenchWindowActionDelegate {

}
